package server.worldgen;

import java.util.Arrays;
import java.util.Set;

import common.biome.BaseBiome;
import common.util.BlockPos;
import common.worldgen.BiomeGenerator;

public class BiomeGenSingle implements BiomeGenerator {
	private final BaseBiome biome;

	public BiomeGenSingle(BaseBiome biome) {
		this.biome = biome;
	}

	public BaseBiome getBiomeGenerator(BlockPos pos, BaseBiome def) {
		return this.biome;
	}

	public void getGenBiomes(BaseBiome[] biomes, int x, int z, int width, int height) {
		Arrays.fill(biomes, 0, width * height, this.biome);
	}

	public void getChunkBiomes(BaseBiome[] oldBiomeList, int x, int z, int width, int depth) {
		Arrays.fill(oldBiomeList, 0, width * depth, this.biome);
	}

	public void getBiomes(BaseBiome[] listToReuse, int x, int z, int width, int length, boolean cache) {
		Arrays.fill(listToReuse, 0, width * length, this.biome);
	}

//	public BlockPos findBiomePosition(int x, int z, int range, Set<Biome> biomes, Random random) {
//		return biomes.contains(this.biome) ? new BlockPos(x - range + random.zrange(range * 2 + 1), 0, z - range + random.zrange(range * 2 + 1))
//				: null;
//	}

	public boolean areBiomesViable(int x, int z, int size, Set<BaseBiome> allowed) {
		return allowed.contains(this.biome);
	}

	public void cleanupCache() {
	}
	
	public void genFactors(double[] factors, int xPos, int zPos, int sizeX, int sizeZ) {
		Arrays.fill(factors, 0, sizeX * sizeZ, this.biome.getFactor());
	}
}
