package server.worldgen.layer;

import common.biome.BaseBiome;
import common.log.Log;

public class GenLayerHills extends GenLayer
{
    private GenLayer field_151628_d;
    private final int def;

    public GenLayerHills(long p_i45479_1_, GenLayer p_i45479_3_, GenLayer p_i45479_4_, BaseBiome def)
    {
        super(p_i45479_1_);
        this.parent = p_i45479_3_;
        this.field_151628_d = p_i45479_4_;
        this.def = def.id;
    }

    /**
     * Returns a list of integer values generated by this layer. These may be interpreted as temperatures, rainfall
     * amounts, or biomeList[] indices based on the particular GenLayer subclass.
     */
    public int[] getInts(int areaX, int areaY, int areaWidth, int areaHeight)
    {
        int[] aint = this.parent.getInts(areaX - 1, areaY - 1, areaWidth + 2, areaHeight + 2);
        int[] aint1 = this.field_151628_d.getInts(areaX - 1, areaY - 1, areaWidth + 2, areaHeight + 2);
        int[] aint2 = IntCache.getIntCache(areaWidth * areaHeight);

        for (int i = 0; i < areaHeight; ++i)
        {
            for (int j = 0; j < areaWidth; ++j)
            {
                this.initChunkSeed((long)(j + areaX), (long)(i + areaY));
                int k = aint[j + 1 + (i + 1) * (areaWidth + 2)];
                int l = aint1[j + 1 + (i + 1) * (areaWidth + 2)];
                boolean flag = (l - 2) % 29 == 0;

                if (k > 255)
                {
                	Log.JNI.warn("Altes Biom (" + k + ")!");
                }

                if (k != 0 && l >= 2 && (l - 2) % 29 == 1 && k < 128)
                {
                    if (BaseBiome.getBiome(k + 128) != null)
                    {
                        aint2[j + i * areaWidth] = k + 128;
                    }
                    else
                    {
                        aint2[j + i * areaWidth] = k;
                    }
                }
                else if (this.nextInt(3) != 0 && !flag)
                {
                    aint2[j + i * areaWidth] = k;
                }
                else
                {
                    int i1 = k;

                    if (k == BaseBiome.DESERT.id)
                    {
                        i1 = BaseBiome.DESERTHILLS.id;
                    }
                    else if (k == BaseBiome.FOREST.id)
                    {
                        i1 = BaseBiome.FORESTHILLS.id;
                    }
                    else if (k == BaseBiome.BIRCHFOREST.id)
                    {
                        i1 = BaseBiome.BIRCHFORESTHILLS.id;
                    }
                    else if (k == BaseBiome.ROOFEDFOREST.id)
                    {
                        i1 = BaseBiome.PLAINS.id;
                    }
                    else if (k == BaseBiome.TAIGA.id)
                    {
                        i1 = BaseBiome.TAIGAHILLS.id;
                    }
                    else if (k == BaseBiome.MEGATAIGA.id)
                    {
                        i1 = BaseBiome.MEGATAIGAHILLS.id;
                    }
                    else if (k == BaseBiome.COLDTAIGA.id)
                    {
                        i1 = BaseBiome.COLDTAIGAHILLS.id;
                    }
                    else if (k == BaseBiome.PLAINS.id)
                    {
                        if (this.nextInt(3) == 0)
                        {
                            i1 = BaseBiome.FORESTHILLS.id;
                        }
                        else
                        {
                            i1 = BaseBiome.FOREST.id;
                        }
                    }
                    else if (k == BaseBiome.ICEPLAINS.id)
                    {
                        i1 = BaseBiome.ICEMOUNTAINS.id;
                    }
                    else if (k == BaseBiome.JUNGLE.id)
                    {
                        i1 = BaseBiome.JUNGLEHILLS.id;
                    }
                    else if (k == BaseBiome.NONE.id)
                    {
                        i1 = this.def;
                    }
                    else if (k == BaseBiome.EXTREMEHILLS.id)
                    {
                        i1 = BaseBiome.EXTREMEHILLSPLUS.id;
                    }
                    else if (k == BaseBiome.SAVANNA.id)
                    {
                        i1 = BaseBiome.SAVANNAPLATEAU.id;
                    }
//                    else if (canBeNearby(k, Biome.mesaPlateau_F.id))
//                    {
//                        i1 = Biome.mesa.id;
//                    }
                    else if (k == BaseBiome.SEA.id && this.nextInt(3) == 0)
                    {
                        int j1 = this.nextInt(2);

                        if (j1 == 0)
                        {
                            i1 = BaseBiome.PLAINS.id;
                        }
                        else
                        {
                            i1 = BaseBiome.FOREST.id;
                        }
                    }

                    if (flag && i1 != k)
                    {
                        if (BaseBiome.getBiome(i1 + 128) != null)
                        {
                            i1 += 128;
                        }
                        else
                        {
                            i1 = k;
                        }
                    }

                    if (i1 == k)
                    {
                        aint2[j + i * areaWidth] = k;
                    }
                    else
                    {
                        int k2 = aint[j + 1 + (i + 1 - 1) * (areaWidth + 2)];
                        int k1 = aint[j + 1 + 1 + (i + 1) * (areaWidth + 2)];
                        int l1 = aint[j + 1 - 1 + (i + 1) * (areaWidth + 2)];
                        int i2 = aint[j + 1 + (i + 1 + 1) * (areaWidth + 2)];
                        int j2 = 0;

                        if (canBeNearby(k2, k))
                        {
                            ++j2;
                        }

                        if (canBeNearby(k1, k))
                        {
                            ++j2;
                        }

                        if (canBeNearby(l1, k))
                        {
                            ++j2;
                        }

                        if (canBeNearby(i2, k))
                        {
                            ++j2;
                        }

                        if (j2 >= 3)
                        {
                            aint2[j + i * areaWidth] = i1;
                        }
                        else
                        {
                            aint2[j + i * areaWidth] = k;
                        }
                    }
                }
            }
        }

        return aint2;
    }
}
